;  "Standard Color Generator"
;  For Bally Arcade/Astrocade
;  By Andy Guevara
;  BASIC EXPRESS, THE 3, no. 2 (May/June 1981): 15-16.
;
;  This program generates 8 standard colors used in TV work.
;   
;  This assembly source code is a combination of the source code
;  available in BASIC EXPRESS, THE 3, no. 2 (May/June 1981): 15-16.
;  and the "Machine Language Manager"  Manual, Page 7-4.
;
;  This program is for use with BALLY BASIC, however, it will NOT
;  run as-is.  It must be loaded with the :RUN command from BASIC,
;  but before that can be done, it must be converted into a 300-baud
;  program file for loading into the Bally BASIC interface.  :RUN
;  expects a file to be 128 bytes (no more and no less).  Since the
;  output of this file is only 68 bytes, that means that the rest
;  of the file needs to be padded-out to 128 bytes if it is to be
;  loaded using :RUN from Bally BASIC.
;
;  This program can be assembled using the ZMAC assembler.  Type:
;
;      zmac -i -m -o STDColor.bin -x STDColor.lst STDColor.asm
;
;  Version History:
;    .02 (Aug 30, 2016)  - Changed source code so that it's output
;                          matches with the Bally BASIC source code
;                          from THE BASIC EXPRESS newsletter. 
;    .01 (July 16, 2013) - First Distributed version.  
;                        - Assemly re-typed and commented by Adam Trionfo
;                        - This source has been kept as true to the
;                          original as possible, which is why it doesn't
;                          use HVGLIB.H and instead uses equates for
;                          CALLs to the ROM routines.

;  Equates

SYSTEM  EQU     $FF            ;  System CALL
SYSSUK  EQU     $FF            ;  System CALL with SUCK option ON
INTPC   EQU     $00            ;  #  0  ; INTerPret with Context create
EXIT    EQU     $02            ;  #  2  ; eXit INTerpreter with Context
SETOUT  EQU     $16            ;  # 22  ; Set Display Ports
COLSET  EQU     $18            ;  # 24  ; COLors SET
RECTAN  EQU     $1C            ;  # 28  ; paint a RECTANgle

        ORG     $4000          ;  Start of Program           	

L4000:  DI                     ;  Disable Interrupts
        DB      SYSSUK         ;  Start Interpreter with SUCK option ON
        DB      INTPC          ;  Begin Interpretering (Multiple CALLs)
        DB      SETOUT+1       ;  Set Display Ports  
        DB      $B6            ;  Blank Line = 182  (VERtical Blanking Line)
        DB      $13            ;  Right/Left Bounds (HORizontal Color Boundary)
        DB      $08            ;  Interrupt Line    (VERtical Blanking Line)
        ;
        DB      COLSET+1       ;  UPI COLors SET (Set Colors)
        DW      L403C          ;  Color List
        DB      EXIT+1         ;  Stop Interpreter         
        LD      BC,$486E       ;  White Border
        LD      A,$55          ;  Color #1
        LD      DE,$0614       ;  XY Position
        DB      SYSTEM         ;  Start Interpreter  
        DB      RECTAN         ;  On-Board ROM Routine - Paint a Rectangle
        LD      HL,L402C       ;  Table Address
        LD      D,$09          ;  Y Position of Bars           
        LD      B,$08          ;  Number of Bars
L401C:  PUSH    BC             ;  Save Count
        LD      A,(HL)         ;  Get Color from Table
        INC     HL             ;  Update Pointer
        LD      E,(HL)         ;  Get X Position from Table 
        INC     HL             ;  Update Pointer
        LD      BC,$420E       ;  Bar Size
        DB      SYSTEM         ;  Begin UPI Interpreting  
        DB      RECTAN         ;  On-Board ROM Routine - Paint a Rectangle
        POP     BC             ;  Get Back Count
        DJNZ    L401C          ;  Loop Back until B=0
        JP      $2544          ;  Back to "AstroBASIC"

;  Color Table
L402C:  DB      $00,$17        ;  Color, X Position
        DB      $55,$24
        DB      $AA,$33
        DB      $FF,$3F
        DB      $00,$4C
        DB      $55,$57
        DB      $AA,$64
        DB      $FF,$71

;  Color List
L403C:  DB      $AC            ; Green---+
        DB      $86            ; Yellow--+-- Left Colors
        DB      $07            ; White   |
        DB      $00            ; Black---+ 
;
        DB      $CD            ; Cyan----+
        DB      $5A            ; Red     +-- Right Colors
        DB      $2B            ; Magenta |
        DB      $F9            ; Blue----+


        ORG    $407F
L407F:  DB     $00             ; Pad-Out the program to 128 bytes

END                            ; End of Program
        